@@ -10,7 +10,7 @@ Acme::Markdown::Embarrassing - Embarrassing the MetaCPAN Markdown converter
 
 =cut
 
-our $VERSION = '2.0';
+our $VERSION = '2.1';
 
 
 =head1 SYNOPSIS
@@ -23,7 +23,7 @@ This is a toy module to embarrass MetaCPAN Markdown
 
 <div style="display: flex">
 <div style="margin: 3px; flex: 1 1 50%">
-<img alt="Test" src="test.png" style="max-width: 100%" width="600">
+<img alt="Test" src="test.png" style="max-width: 100%">
 </div>
 </div>
 
@@ -35,7 +35,7 @@ This is a toy module to embarrass MetaCPAN Markdown
 
 <div style="display: flex">
 <div style="margin: 3px; flex: 1 1 50%">
-<img alt="Test" src="./test.png" style="max-width: 100%" width="600">
+<img alt="Test" src="./test.png" style="max-width: 100%">
 </div>
 </div>
 
@@ -47,7 +47,7 @@ This is a toy module to embarrass MetaCPAN Markdown
 
 <div style="display: flex">
 <div style="margin: 3px; flex: 1 1 50%">
-<img alt="Test" src="../../../test.png" style="max-width: 100%" width="600">
+<img alt="Test" src="../../../test.png" style="max-width: 100%">
 </div>
 </div>
 
@@ -59,7 +59,7 @@ This is a toy module to embarrass MetaCPAN Markdown
 
 <div style="display: flex">
 <div style="margin: 3px; flex: 1 1 50%">
-<img alt="Test" src="https://metacpan.org/source/CONTRA/Acme-Markdown-Embarrassing-1.6/test.png" style="max-width: 100%" width="600">
+<img alt="Test" src="https://metacpan.org/source/CONTRA/Acme-Markdown-Embarrassing-1.6/test.png" style="max-width: 100%"">
 </div>
 </div>
 
@@ -71,7 +71,7 @@ This is a toy module to embarrass MetaCPAN Markdown
 
 <div style="display: flex">
 <div style="margin: 3px; flex: 1 1 50%">
-<img alt="Test" src="https://fastapi.metacpan.org/source/CONTRA/Acme-Markdown-Embarrassing-1.6/test.png" style="max-width: 100%" width="600">
+<img alt="Test" src="https://fastapi.metacpan.org/source/CONTRA/Acme-Markdown-Embarrassing-1.6/test.png" style="max-width: 100%">
 </div>
 </div>
 
@@ -83,7 +83,7 @@ This is a toy module to embarrass MetaCPAN Markdown
 
 <div style="display: flex">
 <div style="margin: 3px; flex: 1 1 50%">
-<img alt="Test" src="https://raw.githubusercontent.com/thibaultduponchelle/Acme-Markdown-Embarrassing/master/test.png" style="max-width: 100%" width="600">
+<img alt="Test" src="https://raw.githubusercontent.com/thibaultduponchelle/Acme-Markdown-Embarrassing/master/test.png" style="max-width: 100%">
 </div>
 </div>
 
